# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetConfigsResult',
    'AwaitableGetConfigsResult',
    'get_configs',
    'get_configs_output',
]

@pulumi.output_type
class GetConfigsResult:
    """
    A collection of values returned by getConfigs.
    """
    def __init__(__self__, configs=None, id=None, ids=None, lang=None, output_file=None):
        if configs and not isinstance(configs, list):
            raise TypeError("Expected argument 'configs' to be a list")
        pulumi.set(__self__, "configs", configs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if lang and not isinstance(lang, str):
            raise TypeError("Expected argument 'lang' to be a str")
        pulumi.set(__self__, "lang", lang)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def configs(self) -> Sequence['outputs.GetConfigsConfigResult']:
        return pulumi.get(self, "configs")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def lang(self) -> Optional[str]:
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetConfigsResult(GetConfigsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConfigsResult(
            configs=self.configs,
            id=self.id,
            ids=self.ids,
            lang=self.lang,
            output_file=self.output_file)


def get_configs(ids: Optional[Sequence[str]] = None,
                lang: Optional[str] = None,
                output_file: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConfigsResult:
    """
    This data source provides the Sddp Configs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.133.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_config = alicloud.sddp.Config("defaultConfig",
        code="access_failed_cnt",
        value="10")
    default_configs = alicloud.sddp.get_configs_output(ids=[default_config.id],
        output_file="./t.json")
    pulumi.export("sddpConfigId", default_configs.ids)
    ```


    :param Sequence[str] ids: A list of Config IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['lang'] = lang
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:sddp/getConfigs:getConfigs', __args__, opts=opts, typ=GetConfigsResult).value

    return AwaitableGetConfigsResult(
        configs=pulumi.get(__ret__, 'configs'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        lang=pulumi.get(__ret__, 'lang'),
        output_file=pulumi.get(__ret__, 'output_file'))


@_utilities.lift_output_func(get_configs)
def get_configs_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                       lang: Optional[pulumi.Input[Optional[str]]] = None,
                       output_file: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetConfigsResult]:
    """
    This data source provides the Sddp Configs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.133.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_config = alicloud.sddp.Config("defaultConfig",
        code="access_failed_cnt",
        value="10")
    default_configs = alicloud.sddp.get_configs_output(ids=[default_config.id],
        output_file="./t.json")
    pulumi.export("sddpConfigId", default_configs.ids)
    ```


    :param Sequence[str] ids: A list of Config IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'NestServiceInstanceCommodity',
    'NestServiceInstanceOperationMetadata',
    'GetNestServiceInstancesFilterResult',
    'GetNestServiceInstancesServiceInstanceResult',
    'GetNestServiceInstancesServiceInstanceServiceResult',
    'GetNestServiceInstancesServiceInstanceServiceServiceInfoResult',
]

@pulumi.output_type
class NestServiceInstanceCommodity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "payPeriod":
            suggest = "pay_period"
        elif key == "payPeriodUnit":
            suggest = "pay_period_unit"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NestServiceInstanceCommodity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NestServiceInstanceCommodity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NestServiceInstanceCommodity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 pay_period: Optional[int] = None,
                 pay_period_unit: Optional[str] = None):
        """
        :param int pay_period: Length of purchase.
        :param str pay_period_unit: Duration unit. Valid values: `Year`, `Month`, `Day`.
        """
        if pay_period is not None:
            pulumi.set(__self__, "pay_period", pay_period)
        if pay_period_unit is not None:
            pulumi.set(__self__, "pay_period_unit", pay_period_unit)

    @property
    @pulumi.getter(name="payPeriod")
    def pay_period(self) -> Optional[int]:
        """
        Length of purchase.
        """
        return pulumi.get(self, "pay_period")

    @property
    @pulumi.getter(name="payPeriodUnit")
    def pay_period_unit(self) -> Optional[str]:
        """
        Duration unit. Valid values: `Year`, `Month`, `Day`.
        """
        return pulumi.get(self, "pay_period_unit")


@pulumi.output_type
class NestServiceInstanceOperationMetadata(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "operatedServiceInstanceId":
            suggest = "operated_service_instance_id"
        elif key == "operationEndTime":
            suggest = "operation_end_time"
        elif key == "operationStartTime":
            suggest = "operation_start_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in NestServiceInstanceOperationMetadata. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        NestServiceInstanceOperationMetadata.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        NestServiceInstanceOperationMetadata.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 operated_service_instance_id: Optional[str] = None,
                 operation_end_time: Optional[str] = None,
                 operation_start_time: Optional[str] = None,
                 resources: Optional[str] = None):
        """
        :param str operated_service_instance_id: The ID of the imported service instance.
        :param str operation_end_time: The end time of O&M.
        :param str operation_start_time: The start time of O&M.
        :param str resources: The list of imported resources.
        """
        if operated_service_instance_id is not None:
            pulumi.set(__self__, "operated_service_instance_id", operated_service_instance_id)
        if operation_end_time is not None:
            pulumi.set(__self__, "operation_end_time", operation_end_time)
        if operation_start_time is not None:
            pulumi.set(__self__, "operation_start_time", operation_start_time)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter(name="operatedServiceInstanceId")
    def operated_service_instance_id(self) -> Optional[str]:
        """
        The ID of the imported service instance.
        """
        return pulumi.get(self, "operated_service_instance_id")

    @property
    @pulumi.getter(name="operationEndTime")
    def operation_end_time(self) -> Optional[str]:
        """
        The end time of O&M.
        """
        return pulumi.get(self, "operation_end_time")

    @property
    @pulumi.getter(name="operationStartTime")
    def operation_start_time(self) -> Optional[str]:
        """
        The start time of O&M.
        """
        return pulumi.get(self, "operation_start_time")

    @property
    @pulumi.getter
    def resources(self) -> Optional[str]:
        """
        The list of imported resources.
        """
        return pulumi.get(self, "resources")


@pulumi.output_type
class GetNestServiceInstancesFilterResult(dict):
    def __init__(__self__, *,
                 name: Optional[str] = None,
                 values: Optional[Sequence[str]] = None):
        """
        :param str name: The name of the filter. Valid Values: `Name`, `ServiceInstanceName`, `ServiceInstanceId`, `ServiceId`, `Version`, `Status`, `DeployType`, `ServiceType`, `OperationStartTimeBefore`, `OperationStartTimeAfter`, `OperationEndTimeBefore`, `OperationEndTimeAfter`, `OperatedServiceInstanceId`, `OperationServiceInstanceId`, `EnableInstanceOps`.
        :param Sequence[str] values: Set of values that are accepted for the given field.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the filter. Valid Values: `Name`, `ServiceInstanceName`, `ServiceInstanceId`, `ServiceId`, `Version`, `Status`, `DeployType`, `ServiceType`, `OperationStartTimeBefore`, `OperationStartTimeAfter`, `OperationEndTimeBefore`, `OperationEndTimeAfter`, `OperatedServiceInstanceId`, `OperationServiceInstanceId`, `EnableInstanceOps`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Optional[Sequence[str]]:
        """
        Set of values that are accepted for the given field.
        """
        return pulumi.get(self, "values")


@pulumi.output_type
class GetNestServiceInstancesServiceInstanceResult(dict):
    def __init__(__self__, *,
                 enable_instance_ops: bool,
                 id: str,
                 operated_service_instance_id: str,
                 operation_end_time: str,
                 operation_start_time: str,
                 parameters: str,
                 resources: str,
                 service_instance_id: str,
                 service_instance_name: str,
                 services: Sequence['outputs.GetNestServiceInstancesServiceInstanceServiceResult'],
                 source: str,
                 status: str,
                 tags: Mapping[str, Any],
                 template_name: str):
        """
        :param bool enable_instance_ops: Whether the service instance has the O&M function.
        :param str id: The ID of the Service Instance.
        :param str operated_service_instance_id: The ID of the imported service instance.
        :param str operation_end_time: The end time of O&M.
        :param str operation_start_time: The start time of O&M.
        :param str parameters: The parameters entered by the deployment service instance.
        :param str resources: The list of imported resources.
        :param str service_instance_id: The ID of the Service Instance.
        :param str service_instance_name: The name of the Service Instance.
        :param Sequence['GetNestServiceInstancesServiceInstanceServiceArgs'] services: Service details.
        :param str source: The source of the Service Instance.
        :param str status: The status of the Service Instance. Valid Values: `Created`, `Deploying`, `DeployedFailed`, `Deployed`, `Upgrading`, `Deleting`, `Deleted`, `DeletedFailed`.
        :param Mapping[str, Any] tags: A mapping of tags to assign to the resource.
        :param str template_name: The name of the template.
        """
        pulumi.set(__self__, "enable_instance_ops", enable_instance_ops)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "operated_service_instance_id", operated_service_instance_id)
        pulumi.set(__self__, "operation_end_time", operation_end_time)
        pulumi.set(__self__, "operation_start_time", operation_start_time)
        pulumi.set(__self__, "parameters", parameters)
        pulumi.set(__self__, "resources", resources)
        pulumi.set(__self__, "service_instance_id", service_instance_id)
        pulumi.set(__self__, "service_instance_name", service_instance_name)
        pulumi.set(__self__, "services", services)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "template_name", template_name)

    @property
    @pulumi.getter(name="enableInstanceOps")
    def enable_instance_ops(self) -> bool:
        """
        Whether the service instance has the O&M function.
        """
        return pulumi.get(self, "enable_instance_ops")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Service Instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="operatedServiceInstanceId")
    def operated_service_instance_id(self) -> str:
        """
        The ID of the imported service instance.
        """
        return pulumi.get(self, "operated_service_instance_id")

    @property
    @pulumi.getter(name="operationEndTime")
    def operation_end_time(self) -> str:
        """
        The end time of O&M.
        """
        return pulumi.get(self, "operation_end_time")

    @property
    @pulumi.getter(name="operationStartTime")
    def operation_start_time(self) -> str:
        """
        The start time of O&M.
        """
        return pulumi.get(self, "operation_start_time")

    @property
    @pulumi.getter
    def parameters(self) -> str:
        """
        The parameters entered by the deployment service instance.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter
    def resources(self) -> str:
        """
        The list of imported resources.
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="serviceInstanceId")
    def service_instance_id(self) -> str:
        """
        The ID of the Service Instance.
        """
        return pulumi.get(self, "service_instance_id")

    @property
    @pulumi.getter(name="serviceInstanceName")
    def service_instance_name(self) -> str:
        """
        The name of the Service Instance.
        """
        return pulumi.get(self, "service_instance_name")

    @property
    @pulumi.getter
    def services(self) -> Sequence['outputs.GetNestServiceInstancesServiceInstanceServiceResult']:
        """
        Service details.
        """
        return pulumi.get(self, "services")

    @property
    @pulumi.getter
    def source(self) -> str:
        """
        The source of the Service Instance.
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the Service Instance. Valid Values: `Created`, `Deploying`, `DeployedFailed`, `Deployed`, `Upgrading`, `Deleting`, `Deleted`, `DeletedFailed`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> str:
        """
        The name of the template.
        """
        return pulumi.get(self, "template_name")


@pulumi.output_type
class GetNestServiceInstancesServiceInstanceServiceResult(dict):
    def __init__(__self__, *,
                 deploy_type: str,
                 publish_time: str,
                 service_id: str,
                 service_infos: Sequence['outputs.GetNestServiceInstancesServiceInstanceServiceServiceInfoResult'],
                 service_type: str,
                 status: str,
                 supplier_name: str,
                 supplier_url: str,
                 version: str,
                 version_name: str):
        """
        :param str deploy_type: The type of the deployment.
        :param str publish_time: The time of publish.
        :param str service_id: The id of the service.
        :param Sequence['GetNestServiceInstancesServiceInstanceServiceServiceInfoArgs'] service_infos: Service information.
        :param str service_type: The type of the service.
        :param str status: The status of the Service Instance. Valid Values: `Created`, `Deploying`, `DeployedFailed`, `Deployed`, `Upgrading`, `Deleting`, `Deleted`, `DeletedFailed`.
        :param str supplier_name: The name of the supplier.
        :param str supplier_url: The url of the supplier.
        :param str version: The version of the service.
        :param str version_name: The version name of the service.
        """
        pulumi.set(__self__, "deploy_type", deploy_type)
        pulumi.set(__self__, "publish_time", publish_time)
        pulumi.set(__self__, "service_id", service_id)
        pulumi.set(__self__, "service_infos", service_infos)
        pulumi.set(__self__, "service_type", service_type)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "supplier_name", supplier_name)
        pulumi.set(__self__, "supplier_url", supplier_url)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "version_name", version_name)

    @property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> str:
        """
        The type of the deployment.
        """
        return pulumi.get(self, "deploy_type")

    @property
    @pulumi.getter(name="publishTime")
    def publish_time(self) -> str:
        """
        The time of publish.
        """
        return pulumi.get(self, "publish_time")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> str:
        """
        The id of the service.
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceInfos")
    def service_infos(self) -> Sequence['outputs.GetNestServiceInstancesServiceInstanceServiceServiceInfoResult']:
        """
        Service information.
        """
        return pulumi.get(self, "service_infos")

    @property
    @pulumi.getter(name="serviceType")
    def service_type(self) -> str:
        """
        The type of the service.
        """
        return pulumi.get(self, "service_type")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the Service Instance. Valid Values: `Created`, `Deploying`, `DeployedFailed`, `Deployed`, `Upgrading`, `Deleting`, `Deleted`, `DeletedFailed`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supplierName")
    def supplier_name(self) -> str:
        """
        The name of the supplier.
        """
        return pulumi.get(self, "supplier_name")

    @property
    @pulumi.getter(name="supplierUrl")
    def supplier_url(self) -> str:
        """
        The url of the supplier.
        """
        return pulumi.get(self, "supplier_url")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the service.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="versionName")
    def version_name(self) -> str:
        """
        The version name of the service.
        """
        return pulumi.get(self, "version_name")


@pulumi.output_type
class GetNestServiceInstancesServiceInstanceServiceServiceInfoResult(dict):
    def __init__(__self__, *,
                 image: str,
                 locale: str,
                 name: str,
                 short_description: str):
        """
        :param str image: The image of the service.
        :param str locale: The locale of the service.
        :param str name: The name of the filter. Valid Values: `Name`, `ServiceInstanceName`, `ServiceInstanceId`, `ServiceId`, `Version`, `Status`, `DeployType`, `ServiceType`, `OperationStartTimeBefore`, `OperationStartTimeAfter`, `OperationEndTimeBefore`, `OperationEndTimeAfter`, `OperatedServiceInstanceId`, `OperationServiceInstanceId`, `EnableInstanceOps`.
        :param str short_description: The short description of the service.
        """
        pulumi.set(__self__, "image", image)
        pulumi.set(__self__, "locale", locale)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "short_description", short_description)

    @property
    @pulumi.getter
    def image(self) -> str:
        """
        The image of the service.
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter
    def locale(self) -> str:
        """
        The locale of the service.
        """
        return pulumi.get(self, "locale")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the filter. Valid Values: `Name`, `ServiceInstanceName`, `ServiceInstanceId`, `ServiceId`, `Version`, `Status`, `DeployType`, `ServiceType`, `OperationStartTimeBefore`, `OperationStartTimeAfter`, `OperationEndTimeBefore`, `OperationEndTimeAfter`, `OperatedServiceInstanceId`, `OperationServiceInstanceId`, `EnableInstanceOps`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="shortDescription")
    def short_description(self) -> str:
        """
        The short description of the service.
        """
        return pulumi.get(self, "short_description")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['MachineGroupArgs', 'MachineGroup']

@pulumi.input_type
class MachineGroupArgs:
    def __init__(__self__, *,
                 identify_lists: pulumi.Input[Sequence[pulumi.Input[str]]],
                 project: pulumi.Input[str],
                 identify_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MachineGroup resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identify_lists: The specific machine identification, which can be an IP address or user-defined identity.
        :param pulumi.Input[str] project: The project name to the machine group belongs.
        :param pulumi.Input[str] identify_type: The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
        :param pulumi.Input[str] name: The machine group name, which is unique in the same project.
        :param pulumi.Input[str] topic: The topic of a machine group.
        """
        pulumi.set(__self__, "identify_lists", identify_lists)
        pulumi.set(__self__, "project", project)
        if identify_type is not None:
            pulumi.set(__self__, "identify_type", identify_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)

    @property
    @pulumi.getter(name="identifyLists")
    def identify_lists(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The specific machine identification, which can be an IP address or user-defined identity.
        """
        return pulumi.get(self, "identify_lists")

    @identify_lists.setter
    def identify_lists(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "identify_lists", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The project name to the machine group belongs.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="identifyType")
    def identify_type(self) -> Optional[pulumi.Input[str]]:
        """
        The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
        """
        return pulumi.get(self, "identify_type")

    @identify_type.setter
    def identify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "identify_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The machine group name, which is unique in the same project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def topic(self) -> Optional[pulumi.Input[str]]:
        """
        The topic of a machine group.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic", value)


@pulumi.input_type
class _MachineGroupState:
    def __init__(__self__, *,
                 identify_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 identify_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MachineGroup resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identify_lists: The specific machine identification, which can be an IP address or user-defined identity.
        :param pulumi.Input[str] identify_type: The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
        :param pulumi.Input[str] name: The machine group name, which is unique in the same project.
        :param pulumi.Input[str] project: The project name to the machine group belongs.
        :param pulumi.Input[str] topic: The topic of a machine group.
        """
        if identify_lists is not None:
            pulumi.set(__self__, "identify_lists", identify_lists)
        if identify_type is not None:
            pulumi.set(__self__, "identify_type", identify_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)

    @property
    @pulumi.getter(name="identifyLists")
    def identify_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The specific machine identification, which can be an IP address or user-defined identity.
        """
        return pulumi.get(self, "identify_lists")

    @identify_lists.setter
    def identify_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "identify_lists", value)

    @property
    @pulumi.getter(name="identifyType")
    def identify_type(self) -> Optional[pulumi.Input[str]]:
        """
        The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
        """
        return pulumi.get(self, "identify_type")

    @identify_type.setter
    def identify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "identify_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The machine group name, which is unique in the same project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The project name to the machine group belongs.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def topic(self) -> Optional[pulumi.Input[str]]:
        """
        The topic of a machine group.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic", value)


class MachineGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identify_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 identify_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Log Service manages all the ECS instances whose logs need to be collected by using the Logtail client in the form of machine groups.
         [Refer to details](https://www.alibabacloud.com/help/doc-detail/28966.htm)

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_machine_group = alicloud.log.MachineGroup("exampleMachineGroup",
            project=example_project.name,
            identify_type="ip",
            topic="terraform",
            identify_lists=[
                "10.0.0.1",
                "10.0.0.2",
            ])
        ```
        ## Module Support

        You can use the existing sls-logtail module
        to create logtail config, machine group, install logtail on ECS instances and join instances into machine group one-click.

        ## Import

        Log machine group can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:log/machineGroup:MachineGroup example tf-log:tf-machine-group
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identify_lists: The specific machine identification, which can be an IP address or user-defined identity.
        :param pulumi.Input[str] identify_type: The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
        :param pulumi.Input[str] name: The machine group name, which is unique in the same project.
        :param pulumi.Input[str] project: The project name to the machine group belongs.
        :param pulumi.Input[str] topic: The topic of a machine group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MachineGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Log Service manages all the ECS instances whose logs need to be collected by using the Logtail client in the form of machine groups.
         [Refer to details](https://www.alibabacloud.com/help/doc-detail/28966.htm)

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.RandomInteger("default",
            max=99999,
            min=10000)
        example_project = alicloud.log.Project("exampleProject", description="terraform-example")
        example_machine_group = alicloud.log.MachineGroup("exampleMachineGroup",
            project=example_project.name,
            identify_type="ip",
            topic="terraform",
            identify_lists=[
                "10.0.0.1",
                "10.0.0.2",
            ])
        ```
        ## Module Support

        You can use the existing sls-logtail module
        to create logtail config, machine group, install logtail on ECS instances and join instances into machine group one-click.

        ## Import

        Log machine group can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:log/machineGroup:MachineGroup example tf-log:tf-machine-group
        ```

        :param str resource_name: The name of the resource.
        :param MachineGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MachineGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identify_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 identify_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MachineGroupArgs.__new__(MachineGroupArgs)

            if identify_lists is None and not opts.urn:
                raise TypeError("Missing required property 'identify_lists'")
            __props__.__dict__["identify_lists"] = identify_lists
            __props__.__dict__["identify_type"] = identify_type
            __props__.__dict__["name"] = name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["topic"] = topic
        super(MachineGroup, __self__).__init__(
            'alicloud:log/machineGroup:MachineGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            identify_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            identify_type: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            topic: Optional[pulumi.Input[str]] = None) -> 'MachineGroup':
        """
        Get an existing MachineGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identify_lists: The specific machine identification, which can be an IP address or user-defined identity.
        :param pulumi.Input[str] identify_type: The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
        :param pulumi.Input[str] name: The machine group name, which is unique in the same project.
        :param pulumi.Input[str] project: The project name to the machine group belongs.
        :param pulumi.Input[str] topic: The topic of a machine group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MachineGroupState.__new__(_MachineGroupState)

        __props__.__dict__["identify_lists"] = identify_lists
        __props__.__dict__["identify_type"] = identify_type
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["topic"] = topic
        return MachineGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="identifyLists")
    def identify_lists(self) -> pulumi.Output[Sequence[str]]:
        """
        The specific machine identification, which can be an IP address or user-defined identity.
        """
        return pulumi.get(self, "identify_lists")

    @property
    @pulumi.getter(name="identifyType")
    def identify_type(self) -> pulumi.Output[Optional[str]]:
        """
        The machine identification type, including IP and user-defined identity. Valid values are "ip" and "userdefined". Default to "ip".
        """
        return pulumi.get(self, "identify_type")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The machine group name, which is unique in the same project.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The project name to the machine group belongs.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def topic(self) -> pulumi.Output[Optional[str]]:
        """
        The topic of a machine group.
        """
        return pulumi.get(self, "topic")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['WebLockConfigArgs', 'WebLockConfig']

@pulumi.input_type
class WebLockConfigArgs:
    def __init__(__self__, *,
                 defence_mode: pulumi.Input[str],
                 dir: pulumi.Input[str],
                 local_backup_dir: pulumi.Input[str],
                 mode: pulumi.Input[str],
                 uuid: pulumi.Input[str],
                 exclusive_dir: Optional[pulumi.Input[str]] = None,
                 exclusive_file: Optional[pulumi.Input[str]] = None,
                 exclusive_file_type: Optional[pulumi.Input[str]] = None,
                 inclusive_file_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a WebLockConfig resource.
        :param pulumi.Input[str] defence_mode: Protection mode. Value:-**block**: Intercept-**audit**: Alarm
        :param pulumi.Input[str] dir: Specify the protection directory.
        :param pulumi.Input[str] local_backup_dir: The local backup path is used to protect the safe backup of the Directory.
        :param pulumi.Input[str] mode: Specify the protected directory mode. Value:-**whitelist**: whitelist mode, which protects the added protected directories and file types.-**blacklist**: blacklist mode, which protects all unexcluded subdirectories, file types, and specified files under the added protection directory.
        :param pulumi.Input[str] uuid: Specify the UUID of the server to which you want to add a protection directory.> You can call the DescribeCloudCenterInstances interface to obtain the UUID of the server.
        :param pulumi.Input[str] exclusive_dir: Specify a directory address that does not require Web tamper protection (I. E. Excluded directories).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file: Specify files that do not need to enable tamper protection for web pages (that is, exclude files).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file_type: Specify the type of file that does not require Web tamper protection (that is, the type of excluded file). When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png > The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] inclusive_file_type: Specify the type of file that requires tamper protection. When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png> The protection Mode **Mode** is set to **whitelist**, you need to configure this parameter.
        """
        pulumi.set(__self__, "defence_mode", defence_mode)
        pulumi.set(__self__, "dir", dir)
        pulumi.set(__self__, "local_backup_dir", local_backup_dir)
        pulumi.set(__self__, "mode", mode)
        pulumi.set(__self__, "uuid", uuid)
        if exclusive_dir is not None:
            pulumi.set(__self__, "exclusive_dir", exclusive_dir)
        if exclusive_file is not None:
            pulumi.set(__self__, "exclusive_file", exclusive_file)
        if exclusive_file_type is not None:
            pulumi.set(__self__, "exclusive_file_type", exclusive_file_type)
        if inclusive_file_type is not None:
            pulumi.set(__self__, "inclusive_file_type", inclusive_file_type)

    @property
    @pulumi.getter(name="defenceMode")
    def defence_mode(self) -> pulumi.Input[str]:
        """
        Protection mode. Value:-**block**: Intercept-**audit**: Alarm
        """
        return pulumi.get(self, "defence_mode")

    @defence_mode.setter
    def defence_mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "defence_mode", value)

    @property
    @pulumi.getter
    def dir(self) -> pulumi.Input[str]:
        """
        Specify the protection directory.
        """
        return pulumi.get(self, "dir")

    @dir.setter
    def dir(self, value: pulumi.Input[str]):
        pulumi.set(self, "dir", value)

    @property
    @pulumi.getter(name="localBackupDir")
    def local_backup_dir(self) -> pulumi.Input[str]:
        """
        The local backup path is used to protect the safe backup of the Directory.
        """
        return pulumi.get(self, "local_backup_dir")

    @local_backup_dir.setter
    def local_backup_dir(self, value: pulumi.Input[str]):
        pulumi.set(self, "local_backup_dir", value)

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Input[str]:
        """
        Specify the protected directory mode. Value:-**whitelist**: whitelist mode, which protects the added protected directories and file types.-**blacklist**: blacklist mode, which protects all unexcluded subdirectories, file types, and specified files under the added protection directory.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def uuid(self) -> pulumi.Input[str]:
        """
        Specify the UUID of the server to which you want to add a protection directory.> You can call the DescribeCloudCenterInstances interface to obtain the UUID of the server.
        """
        return pulumi.get(self, "uuid")

    @uuid.setter
    def uuid(self, value: pulumi.Input[str]):
        pulumi.set(self, "uuid", value)

    @property
    @pulumi.getter(name="exclusiveDir")
    def exclusive_dir(self) -> Optional[pulumi.Input[str]]:
        """
        Specify a directory address that does not require Web tamper protection (I. E. Excluded directories).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_dir")

    @exclusive_dir.setter
    def exclusive_dir(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclusive_dir", value)

    @property
    @pulumi.getter(name="exclusiveFile")
    def exclusive_file(self) -> Optional[pulumi.Input[str]]:
        """
        Specify files that do not need to enable tamper protection for web pages (that is, exclude files).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_file")

    @exclusive_file.setter
    def exclusive_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclusive_file", value)

    @property
    @pulumi.getter(name="exclusiveFileType")
    def exclusive_file_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the type of file that does not require Web tamper protection (that is, the type of excluded file). When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png > The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_file_type")

    @exclusive_file_type.setter
    def exclusive_file_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclusive_file_type", value)

    @property
    @pulumi.getter(name="inclusiveFileType")
    def inclusive_file_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the type of file that requires tamper protection. When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png> The protection Mode **Mode** is set to **whitelist**, you need to configure this parameter.
        """
        return pulumi.get(self, "inclusive_file_type")

    @inclusive_file_type.setter
    def inclusive_file_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "inclusive_file_type", value)


@pulumi.input_type
class _WebLockConfigState:
    def __init__(__self__, *,
                 defence_mode: Optional[pulumi.Input[str]] = None,
                 dir: Optional[pulumi.Input[str]] = None,
                 exclusive_dir: Optional[pulumi.Input[str]] = None,
                 exclusive_file: Optional[pulumi.Input[str]] = None,
                 exclusive_file_type: Optional[pulumi.Input[str]] = None,
                 inclusive_file_type: Optional[pulumi.Input[str]] = None,
                 local_backup_dir: Optional[pulumi.Input[str]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 uuid: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering WebLockConfig resources.
        :param pulumi.Input[str] defence_mode: Protection mode. Value:-**block**: Intercept-**audit**: Alarm
        :param pulumi.Input[str] dir: Specify the protection directory.
        :param pulumi.Input[str] exclusive_dir: Specify a directory address that does not require Web tamper protection (I. E. Excluded directories).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file: Specify files that do not need to enable tamper protection for web pages (that is, exclude files).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file_type: Specify the type of file that does not require Web tamper protection (that is, the type of excluded file). When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png > The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] inclusive_file_type: Specify the type of file that requires tamper protection. When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png> The protection Mode **Mode** is set to **whitelist**, you need to configure this parameter.
        :param pulumi.Input[str] local_backup_dir: The local backup path is used to protect the safe backup of the Directory.
        :param pulumi.Input[str] mode: Specify the protected directory mode. Value:-**whitelist**: whitelist mode, which protects the added protected directories and file types.-**blacklist**: blacklist mode, which protects all unexcluded subdirectories, file types, and specified files under the added protection directory.
        :param pulumi.Input[str] uuid: Specify the UUID of the server to which you want to add a protection directory.> You can call the DescribeCloudCenterInstances interface to obtain the UUID of the server.
        """
        if defence_mode is not None:
            pulumi.set(__self__, "defence_mode", defence_mode)
        if dir is not None:
            pulumi.set(__self__, "dir", dir)
        if exclusive_dir is not None:
            pulumi.set(__self__, "exclusive_dir", exclusive_dir)
        if exclusive_file is not None:
            pulumi.set(__self__, "exclusive_file", exclusive_file)
        if exclusive_file_type is not None:
            pulumi.set(__self__, "exclusive_file_type", exclusive_file_type)
        if inclusive_file_type is not None:
            pulumi.set(__self__, "inclusive_file_type", inclusive_file_type)
        if local_backup_dir is not None:
            pulumi.set(__self__, "local_backup_dir", local_backup_dir)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if uuid is not None:
            pulumi.set(__self__, "uuid", uuid)

    @property
    @pulumi.getter(name="defenceMode")
    def defence_mode(self) -> Optional[pulumi.Input[str]]:
        """
        Protection mode. Value:-**block**: Intercept-**audit**: Alarm
        """
        return pulumi.get(self, "defence_mode")

    @defence_mode.setter
    def defence_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defence_mode", value)

    @property
    @pulumi.getter
    def dir(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the protection directory.
        """
        return pulumi.get(self, "dir")

    @dir.setter
    def dir(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dir", value)

    @property
    @pulumi.getter(name="exclusiveDir")
    def exclusive_dir(self) -> Optional[pulumi.Input[str]]:
        """
        Specify a directory address that does not require Web tamper protection (I. E. Excluded directories).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_dir")

    @exclusive_dir.setter
    def exclusive_dir(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclusive_dir", value)

    @property
    @pulumi.getter(name="exclusiveFile")
    def exclusive_file(self) -> Optional[pulumi.Input[str]]:
        """
        Specify files that do not need to enable tamper protection for web pages (that is, exclude files).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_file")

    @exclusive_file.setter
    def exclusive_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclusive_file", value)

    @property
    @pulumi.getter(name="exclusiveFileType")
    def exclusive_file_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the type of file that does not require Web tamper protection (that is, the type of excluded file). When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png > The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_file_type")

    @exclusive_file_type.setter
    def exclusive_file_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclusive_file_type", value)

    @property
    @pulumi.getter(name="inclusiveFileType")
    def inclusive_file_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the type of file that requires tamper protection. When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png> The protection Mode **Mode** is set to **whitelist**, you need to configure this parameter.
        """
        return pulumi.get(self, "inclusive_file_type")

    @inclusive_file_type.setter
    def inclusive_file_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "inclusive_file_type", value)

    @property
    @pulumi.getter(name="localBackupDir")
    def local_backup_dir(self) -> Optional[pulumi.Input[str]]:
        """
        The local backup path is used to protect the safe backup of the Directory.
        """
        return pulumi.get(self, "local_backup_dir")

    @local_backup_dir.setter
    def local_backup_dir(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_backup_dir", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the protected directory mode. Value:-**whitelist**: whitelist mode, which protects the added protected directories and file types.-**blacklist**: blacklist mode, which protects all unexcluded subdirectories, file types, and specified files under the added protection directory.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def uuid(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the UUID of the server to which you want to add a protection directory.> You can call the DescribeCloudCenterInstances interface to obtain the UUID of the server.
        """
        return pulumi.get(self, "uuid")

    @uuid.setter
    def uuid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uuid", value)


class WebLockConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defence_mode: Optional[pulumi.Input[str]] = None,
                 dir: Optional[pulumi.Input[str]] = None,
                 exclusive_dir: Optional[pulumi.Input[str]] = None,
                 exclusive_file: Optional[pulumi.Input[str]] = None,
                 exclusive_file_type: Optional[pulumi.Input[str]] = None,
                 inclusive_file_type: Optional[pulumi.Input[str]] = None,
                 local_backup_dir: Optional[pulumi.Input[str]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 uuid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Threat Detection Web Lock Config resource.

        For information about Threat Detection Web Lock Config and how to use it, see [What is Web Lock Config](https://www.alibabacloud.com/help/en/security-center/latest/api-doc-sas-2018-12-03-api-doc-modifyweblockstart).

        > **NOTE:** Available in v1.195.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_assets = alicloud.threatdetection.get_assets(machine_types="ecs")
        default_web_lock_config = alicloud.threatdetection.WebLockConfig("defaultWebLockConfig",
            inclusive_file_type="php;jsp;asp;aspx;js;cgi;html;htm;xml;shtml;shtm;jpg",
            uuid=default_assets.ids[0],
            mode="whitelist",
            local_backup_dir="/usr/local/aegis/bak",
            dir="/tmp/",
            defence_mode="audit")
        ```

        ## Import

        Threat Detection Web Lock Config can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:threatdetection/webLockConfig:WebLockConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defence_mode: Protection mode. Value:-**block**: Intercept-**audit**: Alarm
        :param pulumi.Input[str] dir: Specify the protection directory.
        :param pulumi.Input[str] exclusive_dir: Specify a directory address that does not require Web tamper protection (I. E. Excluded directories).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file: Specify files that do not need to enable tamper protection for web pages (that is, exclude files).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file_type: Specify the type of file that does not require Web tamper protection (that is, the type of excluded file). When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png > The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] inclusive_file_type: Specify the type of file that requires tamper protection. When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png> The protection Mode **Mode** is set to **whitelist**, you need to configure this parameter.
        :param pulumi.Input[str] local_backup_dir: The local backup path is used to protect the safe backup of the Directory.
        :param pulumi.Input[str] mode: Specify the protected directory mode. Value:-**whitelist**: whitelist mode, which protects the added protected directories and file types.-**blacklist**: blacklist mode, which protects all unexcluded subdirectories, file types, and specified files under the added protection directory.
        :param pulumi.Input[str] uuid: Specify the UUID of the server to which you want to add a protection directory.> You can call the DescribeCloudCenterInstances interface to obtain the UUID of the server.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WebLockConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Threat Detection Web Lock Config resource.

        For information about Threat Detection Web Lock Config and how to use it, see [What is Web Lock Config](https://www.alibabacloud.com/help/en/security-center/latest/api-doc-sas-2018-12-03-api-doc-modifyweblockstart).

        > **NOTE:** Available in v1.195.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_assets = alicloud.threatdetection.get_assets(machine_types="ecs")
        default_web_lock_config = alicloud.threatdetection.WebLockConfig("defaultWebLockConfig",
            inclusive_file_type="php;jsp;asp;aspx;js;cgi;html;htm;xml;shtml;shtm;jpg",
            uuid=default_assets.ids[0],
            mode="whitelist",
            local_backup_dir="/usr/local/aegis/bak",
            dir="/tmp/",
            defence_mode="audit")
        ```

        ## Import

        Threat Detection Web Lock Config can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:threatdetection/webLockConfig:WebLockConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param WebLockConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WebLockConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defence_mode: Optional[pulumi.Input[str]] = None,
                 dir: Optional[pulumi.Input[str]] = None,
                 exclusive_dir: Optional[pulumi.Input[str]] = None,
                 exclusive_file: Optional[pulumi.Input[str]] = None,
                 exclusive_file_type: Optional[pulumi.Input[str]] = None,
                 inclusive_file_type: Optional[pulumi.Input[str]] = None,
                 local_backup_dir: Optional[pulumi.Input[str]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 uuid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WebLockConfigArgs.__new__(WebLockConfigArgs)

            if defence_mode is None and not opts.urn:
                raise TypeError("Missing required property 'defence_mode'")
            __props__.__dict__["defence_mode"] = defence_mode
            if dir is None and not opts.urn:
                raise TypeError("Missing required property 'dir'")
            __props__.__dict__["dir"] = dir
            __props__.__dict__["exclusive_dir"] = exclusive_dir
            __props__.__dict__["exclusive_file"] = exclusive_file
            __props__.__dict__["exclusive_file_type"] = exclusive_file_type
            __props__.__dict__["inclusive_file_type"] = inclusive_file_type
            if local_backup_dir is None and not opts.urn:
                raise TypeError("Missing required property 'local_backup_dir'")
            __props__.__dict__["local_backup_dir"] = local_backup_dir
            if mode is None and not opts.urn:
                raise TypeError("Missing required property 'mode'")
            __props__.__dict__["mode"] = mode
            if uuid is None and not opts.urn:
                raise TypeError("Missing required property 'uuid'")
            __props__.__dict__["uuid"] = uuid
        super(WebLockConfig, __self__).__init__(
            'alicloud:threatdetection/webLockConfig:WebLockConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            defence_mode: Optional[pulumi.Input[str]] = None,
            dir: Optional[pulumi.Input[str]] = None,
            exclusive_dir: Optional[pulumi.Input[str]] = None,
            exclusive_file: Optional[pulumi.Input[str]] = None,
            exclusive_file_type: Optional[pulumi.Input[str]] = None,
            inclusive_file_type: Optional[pulumi.Input[str]] = None,
            local_backup_dir: Optional[pulumi.Input[str]] = None,
            mode: Optional[pulumi.Input[str]] = None,
            uuid: Optional[pulumi.Input[str]] = None) -> 'WebLockConfig':
        """
        Get an existing WebLockConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defence_mode: Protection mode. Value:-**block**: Intercept-**audit**: Alarm
        :param pulumi.Input[str] dir: Specify the protection directory.
        :param pulumi.Input[str] exclusive_dir: Specify a directory address that does not require Web tamper protection (I. E. Excluded directories).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file: Specify files that do not need to enable tamper protection for web pages (that is, exclude files).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] exclusive_file_type: Specify the type of file that does not require Web tamper protection (that is, the type of excluded file). When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png > The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        :param pulumi.Input[str] inclusive_file_type: Specify the type of file that requires tamper protection. When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png> The protection Mode **Mode** is set to **whitelist**, you need to configure this parameter.
        :param pulumi.Input[str] local_backup_dir: The local backup path is used to protect the safe backup of the Directory.
        :param pulumi.Input[str] mode: Specify the protected directory mode. Value:-**whitelist**: whitelist mode, which protects the added protected directories and file types.-**blacklist**: blacklist mode, which protects all unexcluded subdirectories, file types, and specified files under the added protection directory.
        :param pulumi.Input[str] uuid: Specify the UUID of the server to which you want to add a protection directory.> You can call the DescribeCloudCenterInstances interface to obtain the UUID of the server.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WebLockConfigState.__new__(_WebLockConfigState)

        __props__.__dict__["defence_mode"] = defence_mode
        __props__.__dict__["dir"] = dir
        __props__.__dict__["exclusive_dir"] = exclusive_dir
        __props__.__dict__["exclusive_file"] = exclusive_file
        __props__.__dict__["exclusive_file_type"] = exclusive_file_type
        __props__.__dict__["inclusive_file_type"] = inclusive_file_type
        __props__.__dict__["local_backup_dir"] = local_backup_dir
        __props__.__dict__["mode"] = mode
        __props__.__dict__["uuid"] = uuid
        return WebLockConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="defenceMode")
    def defence_mode(self) -> pulumi.Output[str]:
        """
        Protection mode. Value:-**block**: Intercept-**audit**: Alarm
        """
        return pulumi.get(self, "defence_mode")

    @property
    @pulumi.getter
    def dir(self) -> pulumi.Output[str]:
        """
        Specify the protection directory.
        """
        return pulumi.get(self, "dir")

    @property
    @pulumi.getter(name="exclusiveDir")
    def exclusive_dir(self) -> pulumi.Output[Optional[str]]:
        """
        Specify a directory address that does not require Web tamper protection (I. E. Excluded directories).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_dir")

    @property
    @pulumi.getter(name="exclusiveFile")
    def exclusive_file(self) -> pulumi.Output[Optional[str]]:
        """
        Specify files that do not need to enable tamper protection for web pages (that is, exclude files).> The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_file")

    @property
    @pulumi.getter(name="exclusiveFileType")
    def exclusive_file_type(self) -> pulumi.Output[Optional[str]]:
        """
        Specify the type of file that does not require Web tamper protection (that is, the type of excluded file). When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png > The protection Mode **Mode** is set to **blacklist**, you need to configure this parameter.
        """
        return pulumi.get(self, "exclusive_file_type")

    @property
    @pulumi.getter(name="inclusiveFileType")
    def inclusive_file_type(self) -> pulumi.Output[Optional[str]]:
        """
        Specify the type of file that requires tamper protection. When there are multiple file types, use semicolons (;) separation. Value:-php-jsp-asp-aspx-js-cgi-html-htm-xml-shtml-shtm-jpg-gif-png> The protection Mode **Mode** is set to **whitelist**, you need to configure this parameter.
        """
        return pulumi.get(self, "inclusive_file_type")

    @property
    @pulumi.getter(name="localBackupDir")
    def local_backup_dir(self) -> pulumi.Output[str]:
        """
        The local backup path is used to protect the safe backup of the Directory.
        """
        return pulumi.get(self, "local_backup_dir")

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Output[str]:
        """
        Specify the protected directory mode. Value:-**whitelist**: whitelist mode, which protects the added protected directories and file types.-**blacklist**: blacklist mode, which protects all unexcluded subdirectories, file types, and specified files under the added protection directory.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def uuid(self) -> pulumi.Output[str]:
        """
        Specify the UUID of the server to which you want to add a protection directory.> You can call the DescribeCloudCenterInstances interface to obtain the UUID of the server.
        """
        return pulumi.get(self, "uuid")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetDeviceGroupsGroupResult',
]

@pulumi.output_type
class GetDeviceGroupsGroupResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 device_active: str,
                 device_count: str,
                 device_online: str,
                 error_message: str,
                 group_desc: str,
                 group_id: str,
                 group_name: str,
                 id: str,
                 success: bool):
        """
        :param str create_time: The Group CreateTime.
        :param str device_active: The Group Number of activated devices.
        :param str device_count: The Group Total number of devices.
        :param str device_online: The Group Number of online devices.
        :param str error_message: The Error_Message of the device group.
        :param str group_desc: The GroupDesc of the device group.
        :param str group_id: The GroupId of the device group.
        :param str group_name: The GroupName of the device group.
        :param str id: The ID of the device group.
        :param bool success: Whether the call is successful.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "device_active", device_active)
        pulumi.set(__self__, "device_count", device_count)
        pulumi.set(__self__, "device_online", device_online)
        pulumi.set(__self__, "error_message", error_message)
        pulumi.set(__self__, "group_desc", group_desc)
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "group_name", group_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "success", success)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The Group CreateTime.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deviceActive")
    def device_active(self) -> str:
        """
        The Group Number of activated devices.
        """
        return pulumi.get(self, "device_active")

    @property
    @pulumi.getter(name="deviceCount")
    def device_count(self) -> str:
        """
        The Group Total number of devices.
        """
        return pulumi.get(self, "device_count")

    @property
    @pulumi.getter(name="deviceOnline")
    def device_online(self) -> str:
        """
        The Group Number of online devices.
        """
        return pulumi.get(self, "device_online")

    @property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> str:
        """
        The Error_Message of the device group.
        """
        return pulumi.get(self, "error_message")

    @property
    @pulumi.getter(name="groupDesc")
    def group_desc(self) -> str:
        """
        The GroupDesc of the device group.
        """
        return pulumi.get(self, "group_desc")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> str:
        """
        The GroupId of the device group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> str:
        """
        The GroupName of the device group.
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the device group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def success(self) -> bool:
        """
        Whether the call is successful.
        """
        return pulumi.get(self, "success")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['AclRuleArgs', 'AclRule']

@pulumi.input_type
class AclRuleArgs:
    def __init__(__self__, *,
                 acl_id: pulumi.Input[str],
                 dest_cidr: pulumi.Input[str],
                 dest_port_range: pulumi.Input[str],
                 direction: pulumi.Input[str],
                 ip_protocol: pulumi.Input[str],
                 policy: pulumi.Input[str],
                 source_cidr: pulumi.Input[str],
                 source_port_range: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a AclRule resource.
        :param pulumi.Input[str] acl_id: The ID of the ACL.
        :param pulumi.Input[str] dest_cidr: The destination address. It is an IPv4 address range in CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] dest_port_range: The range of the destination port. Valid value: 80/80.
        :param pulumi.Input[str] direction: The direction of the ACL rule. Valid values: in|out.
        :param pulumi.Input[str] ip_protocol: The protocol used by the ACL rule. The value is not case sensitive.
        :param pulumi.Input[str] policy: The policy used by the ACL rule. Valid values: accept|drop.
        :param pulumi.Input[str] source_cidr: The source address. It is an IPv4 address range in the CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] source_port_range: The range of the source port. Valid value: 80/80.
        :param pulumi.Input[str] description: The description of the ACL rule. It must be 1 to 512 characters in length.
        :param pulumi.Input[int] priority: The priority of the ACL rule. Value range: 1 to 100.
        """
        pulumi.set(__self__, "acl_id", acl_id)
        pulumi.set(__self__, "dest_cidr", dest_cidr)
        pulumi.set(__self__, "dest_port_range", dest_port_range)
        pulumi.set(__self__, "direction", direction)
        pulumi.set(__self__, "ip_protocol", ip_protocol)
        pulumi.set(__self__, "policy", policy)
        pulumi.set(__self__, "source_cidr", source_cidr)
        pulumi.set(__self__, "source_port_range", source_port_range)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> pulumi.Input[str]:
        """
        The ID of the ACL.
        """
        return pulumi.get(self, "acl_id")

    @acl_id.setter
    def acl_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "acl_id", value)

    @property
    @pulumi.getter(name="destCidr")
    def dest_cidr(self) -> pulumi.Input[str]:
        """
        The destination address. It is an IPv4 address range in CIDR format. Default value: 0.0.0.0/0.
        """
        return pulumi.get(self, "dest_cidr")

    @dest_cidr.setter
    def dest_cidr(self, value: pulumi.Input[str]):
        pulumi.set(self, "dest_cidr", value)

    @property
    @pulumi.getter(name="destPortRange")
    def dest_port_range(self) -> pulumi.Input[str]:
        """
        The range of the destination port. Valid value: 80/80.
        """
        return pulumi.get(self, "dest_port_range")

    @dest_port_range.setter
    def dest_port_range(self, value: pulumi.Input[str]):
        pulumi.set(self, "dest_port_range", value)

    @property
    @pulumi.getter
    def direction(self) -> pulumi.Input[str]:
        """
        The direction of the ACL rule. Valid values: in|out.
        """
        return pulumi.get(self, "direction")

    @direction.setter
    def direction(self, value: pulumi.Input[str]):
        pulumi.set(self, "direction", value)

    @property
    @pulumi.getter(name="ipProtocol")
    def ip_protocol(self) -> pulumi.Input[str]:
        """
        The protocol used by the ACL rule. The value is not case sensitive.
        """
        return pulumi.get(self, "ip_protocol")

    @ip_protocol.setter
    def ip_protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "ip_protocol", value)

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Input[str]:
        """
        The policy used by the ACL rule. Valid values: accept|drop.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="sourceCidr")
    def source_cidr(self) -> pulumi.Input[str]:
        """
        The source address. It is an IPv4 address range in the CIDR format. Default value: 0.0.0.0/0.
        """
        return pulumi.get(self, "source_cidr")

    @source_cidr.setter
    def source_cidr(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_cidr", value)

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> pulumi.Input[str]:
        """
        The range of the source port. Valid value: 80/80.
        """
        return pulumi.get(self, "source_port_range")

    @source_port_range.setter
    def source_port_range(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_port_range", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the ACL rule. It must be 1 to 512 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        The priority of the ACL rule. Value range: 1 to 100.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)


@pulumi.input_type
class _AclRuleState:
    def __init__(__self__, *,
                 acl_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dest_cidr: Optional[pulumi.Input[str]] = None,
                 dest_port_range: Optional[pulumi.Input[str]] = None,
                 direction: Optional[pulumi.Input[str]] = None,
                 ip_protocol: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 source_cidr: Optional[pulumi.Input[str]] = None,
                 source_port_range: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AclRule resources.
        :param pulumi.Input[str] acl_id: The ID of the ACL.
        :param pulumi.Input[str] description: The description of the ACL rule. It must be 1 to 512 characters in length.
        :param pulumi.Input[str] dest_cidr: The destination address. It is an IPv4 address range in CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] dest_port_range: The range of the destination port. Valid value: 80/80.
        :param pulumi.Input[str] direction: The direction of the ACL rule. Valid values: in|out.
        :param pulumi.Input[str] ip_protocol: The protocol used by the ACL rule. The value is not case sensitive.
        :param pulumi.Input[str] policy: The policy used by the ACL rule. Valid values: accept|drop.
        :param pulumi.Input[int] priority: The priority of the ACL rule. Value range: 1 to 100.
        :param pulumi.Input[str] source_cidr: The source address. It is an IPv4 address range in the CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] source_port_range: The range of the source port. Valid value: 80/80.
        """
        if acl_id is not None:
            pulumi.set(__self__, "acl_id", acl_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dest_cidr is not None:
            pulumi.set(__self__, "dest_cidr", dest_cidr)
        if dest_port_range is not None:
            pulumi.set(__self__, "dest_port_range", dest_port_range)
        if direction is not None:
            pulumi.set(__self__, "direction", direction)
        if ip_protocol is not None:
            pulumi.set(__self__, "ip_protocol", ip_protocol)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if source_cidr is not None:
            pulumi.set(__self__, "source_cidr", source_cidr)
        if source_port_range is not None:
            pulumi.set(__self__, "source_port_range", source_port_range)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the ACL.
        """
        return pulumi.get(self, "acl_id")

    @acl_id.setter
    def acl_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "acl_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the ACL rule. It must be 1 to 512 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destCidr")
    def dest_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The destination address. It is an IPv4 address range in CIDR format. Default value: 0.0.0.0/0.
        """
        return pulumi.get(self, "dest_cidr")

    @dest_cidr.setter
    def dest_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_cidr", value)

    @property
    @pulumi.getter(name="destPortRange")
    def dest_port_range(self) -> Optional[pulumi.Input[str]]:
        """
        The range of the destination port. Valid value: 80/80.
        """
        return pulumi.get(self, "dest_port_range")

    @dest_port_range.setter
    def dest_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_port_range", value)

    @property
    @pulumi.getter
    def direction(self) -> Optional[pulumi.Input[str]]:
        """
        The direction of the ACL rule. Valid values: in|out.
        """
        return pulumi.get(self, "direction")

    @direction.setter
    def direction(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "direction", value)

    @property
    @pulumi.getter(name="ipProtocol")
    def ip_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The protocol used by the ACL rule. The value is not case sensitive.
        """
        return pulumi.get(self, "ip_protocol")

    @ip_protocol.setter
    def ip_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_protocol", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        The policy used by the ACL rule. Valid values: accept|drop.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        The priority of the ACL rule. Value range: 1 to 100.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="sourceCidr")
    def source_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The source address. It is an IPv4 address range in the CIDR format. Default value: 0.0.0.0/0.
        """
        return pulumi.get(self, "source_cidr")

    @source_cidr.setter
    def source_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_cidr", value)

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> Optional[pulumi.Input[str]]:
        """
        The range of the source port. Valid value: 80/80.
        """
        return pulumi.get(self, "source_port_range")

    @source_port_range.setter
    def source_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_port_range", value)


class AclRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dest_cidr: Optional[pulumi.Input[str]] = None,
                 dest_port_range: Optional[pulumi.Input[str]] = None,
                 direction: Optional[pulumi.Input[str]] = None,
                 ip_protocol: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 source_cidr: Optional[pulumi.Input[str]] = None,
                 source_port_range: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Sag Acl Rule resource. This topic describes how to configure an access control list (ACL) rule for a target Smart Access Gateway instance to permit or deny access to or from specified IP addresses in the ACL rule.

        For information about Sag Acl Rule and how to use it, see [What is access control list (ACL) rule](https://www.alibabacloud.com/help/doc-detail/111483.htm).

        > **NOTE:** Available in 1.60.0+

        > **NOTE:** Only the following regions support create Cloud Connect Network. [`cn-shanghai`, `cn-shanghai-finance-1`, `cn-hongkong`, `ap-southeast-1`, `ap-southeast-2`, `ap-southeast-3`, `ap-southeast-5`, `ap-northeast-1`, `eu-central-1`]

        ## Import

        The Sag Acl Rule can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:rocketmq/aclRule:AclRule example acr-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] acl_id: The ID of the ACL.
        :param pulumi.Input[str] description: The description of the ACL rule. It must be 1 to 512 characters in length.
        :param pulumi.Input[str] dest_cidr: The destination address. It is an IPv4 address range in CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] dest_port_range: The range of the destination port. Valid value: 80/80.
        :param pulumi.Input[str] direction: The direction of the ACL rule. Valid values: in|out.
        :param pulumi.Input[str] ip_protocol: The protocol used by the ACL rule. The value is not case sensitive.
        :param pulumi.Input[str] policy: The policy used by the ACL rule. Valid values: accept|drop.
        :param pulumi.Input[int] priority: The priority of the ACL rule. Value range: 1 to 100.
        :param pulumi.Input[str] source_cidr: The source address. It is an IPv4 address range in the CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] source_port_range: The range of the source port. Valid value: 80/80.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AclRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Sag Acl Rule resource. This topic describes how to configure an access control list (ACL) rule for a target Smart Access Gateway instance to permit or deny access to or from specified IP addresses in the ACL rule.

        For information about Sag Acl Rule and how to use it, see [What is access control list (ACL) rule](https://www.alibabacloud.com/help/doc-detail/111483.htm).

        > **NOTE:** Available in 1.60.0+

        > **NOTE:** Only the following regions support create Cloud Connect Network. [`cn-shanghai`, `cn-shanghai-finance-1`, `cn-hongkong`, `ap-southeast-1`, `ap-southeast-2`, `ap-southeast-3`, `ap-southeast-5`, `ap-northeast-1`, `eu-central-1`]

        ## Import

        The Sag Acl Rule can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:rocketmq/aclRule:AclRule example acr-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param AclRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AclRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dest_cidr: Optional[pulumi.Input[str]] = None,
                 dest_port_range: Optional[pulumi.Input[str]] = None,
                 direction: Optional[pulumi.Input[str]] = None,
                 ip_protocol: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 source_cidr: Optional[pulumi.Input[str]] = None,
                 source_port_range: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AclRuleArgs.__new__(AclRuleArgs)

            if acl_id is None and not opts.urn:
                raise TypeError("Missing required property 'acl_id'")
            __props__.__dict__["acl_id"] = acl_id
            __props__.__dict__["description"] = description
            if dest_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'dest_cidr'")
            __props__.__dict__["dest_cidr"] = dest_cidr
            if dest_port_range is None and not opts.urn:
                raise TypeError("Missing required property 'dest_port_range'")
            __props__.__dict__["dest_port_range"] = dest_port_range
            if direction is None and not opts.urn:
                raise TypeError("Missing required property 'direction'")
            __props__.__dict__["direction"] = direction
            if ip_protocol is None and not opts.urn:
                raise TypeError("Missing required property 'ip_protocol'")
            __props__.__dict__["ip_protocol"] = ip_protocol
            if policy is None and not opts.urn:
                raise TypeError("Missing required property 'policy'")
            __props__.__dict__["policy"] = policy
            __props__.__dict__["priority"] = priority
            if source_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'source_cidr'")
            __props__.__dict__["source_cidr"] = source_cidr
            if source_port_range is None and not opts.urn:
                raise TypeError("Missing required property 'source_port_range'")
            __props__.__dict__["source_port_range"] = source_port_range
        super(AclRule, __self__).__init__(
            'alicloud:rocketmq/aclRule:AclRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acl_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            dest_cidr: Optional[pulumi.Input[str]] = None,
            dest_port_range: Optional[pulumi.Input[str]] = None,
            direction: Optional[pulumi.Input[str]] = None,
            ip_protocol: Optional[pulumi.Input[str]] = None,
            policy: Optional[pulumi.Input[str]] = None,
            priority: Optional[pulumi.Input[int]] = None,
            source_cidr: Optional[pulumi.Input[str]] = None,
            source_port_range: Optional[pulumi.Input[str]] = None) -> 'AclRule':
        """
        Get an existing AclRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] acl_id: The ID of the ACL.
        :param pulumi.Input[str] description: The description of the ACL rule. It must be 1 to 512 characters in length.
        :param pulumi.Input[str] dest_cidr: The destination address. It is an IPv4 address range in CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] dest_port_range: The range of the destination port. Valid value: 80/80.
        :param pulumi.Input[str] direction: The direction of the ACL rule. Valid values: in|out.
        :param pulumi.Input[str] ip_protocol: The protocol used by the ACL rule. The value is not case sensitive.
        :param pulumi.Input[str] policy: The policy used by the ACL rule. Valid values: accept|drop.
        :param pulumi.Input[int] priority: The priority of the ACL rule. Value range: 1 to 100.
        :param pulumi.Input[str] source_cidr: The source address. It is an IPv4 address range in the CIDR format. Default value: 0.0.0.0/0.
        :param pulumi.Input[str] source_port_range: The range of the source port. Valid value: 80/80.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AclRuleState.__new__(_AclRuleState)

        __props__.__dict__["acl_id"] = acl_id
        __props__.__dict__["description"] = description
        __props__.__dict__["dest_cidr"] = dest_cidr
        __props__.__dict__["dest_port_range"] = dest_port_range
        __props__.__dict__["direction"] = direction
        __props__.__dict__["ip_protocol"] = ip_protocol
        __props__.__dict__["policy"] = policy
        __props__.__dict__["priority"] = priority
        __props__.__dict__["source_cidr"] = source_cidr
        __props__.__dict__["source_port_range"] = source_port_range
        return AclRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> pulumi.Output[str]:
        """
        The ID of the ACL.
        """
        return pulumi.get(self, "acl_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the ACL rule. It must be 1 to 512 characters in length.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destCidr")
    def dest_cidr(self) -> pulumi.Output[str]:
        """
        The destination address. It is an IPv4 address range in CIDR format. Default value: 0.0.0.0/0.
        """
        return pulumi.get(self, "dest_cidr")

    @property
    @pulumi.getter(name="destPortRange")
    def dest_port_range(self) -> pulumi.Output[str]:
        """
        The range of the destination port. Valid value: 80/80.
        """
        return pulumi.get(self, "dest_port_range")

    @property
    @pulumi.getter
    def direction(self) -> pulumi.Output[str]:
        """
        The direction of the ACL rule. Valid values: in|out.
        """
        return pulumi.get(self, "direction")

    @property
    @pulumi.getter(name="ipProtocol")
    def ip_protocol(self) -> pulumi.Output[str]:
        """
        The protocol used by the ACL rule. The value is not case sensitive.
        """
        return pulumi.get(self, "ip_protocol")

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Output[str]:
        """
        The policy used by the ACL rule. Valid values: accept|drop.
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Output[Optional[int]]:
        """
        The priority of the ACL rule. Value range: 1 to 100.
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter(name="sourceCidr")
    def source_cidr(self) -> pulumi.Output[str]:
        """
        The source address. It is an IPv4 address range in the CIDR format. Default value: 0.0.0.0/0.
        """
        return pulumi.get(self, "source_cidr")

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> pulumi.Output[str]:
        """
        The range of the source port. Valid value: 80/80.
        """
        return pulumi.get(self, "source_port_range")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetEnterpriseProxiesResult',
    'AwaitableGetEnterpriseProxiesResult',
    'get_enterprise_proxies',
    'get_enterprise_proxies_output',
]

@pulumi.output_type
class GetEnterpriseProxiesResult:
    """
    A collection of values returned by getEnterpriseProxies.
    """
    def __init__(__self__, id=None, ids=None, output_file=None, proxies=None, tid=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if proxies and not isinstance(proxies, list):
            raise TypeError("Expected argument 'proxies' to be a list")
        pulumi.set(__self__, "proxies", proxies)
        if tid and not isinstance(tid, str):
            raise TypeError("Expected argument 'tid' to be a str")
        pulumi.set(__self__, "tid", tid)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def proxies(self) -> Sequence['outputs.GetEnterpriseProxiesProxyResult']:
        return pulumi.get(self, "proxies")

    @property
    @pulumi.getter
    def tid(self) -> Optional[str]:
        return pulumi.get(self, "tid")


class AwaitableGetEnterpriseProxiesResult(GetEnterpriseProxiesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnterpriseProxiesResult(
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            proxies=self.proxies,
            tid=self.tid)


def get_enterprise_proxies(ids: Optional[Sequence[str]] = None,
                           output_file: Optional[str] = None,
                           tid: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnterpriseProxiesResult:
    """
    This data source provides the Dms Enterprise Proxies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.188.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.dms.get_enterprise_proxies()
    pulumi.export("dmsEnterpriseProxyId1", ids.proxies[0].id)
    ```


    :param Sequence[str] ids: A list of Proxy IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str tid: The ID of the tenant.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['tid'] = tid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:dms/getEnterpriseProxies:getEnterpriseProxies', __args__, opts=opts, typ=GetEnterpriseProxiesResult).value

    return AwaitableGetEnterpriseProxiesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        proxies=pulumi.get(__ret__, 'proxies'),
        tid=pulumi.get(__ret__, 'tid'))


@_utilities.lift_output_func(get_enterprise_proxies)
def get_enterprise_proxies_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                  tid: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnterpriseProxiesResult]:
    """
    This data source provides the Dms Enterprise Proxies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.188.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.dms.get_enterprise_proxies()
    pulumi.export("dmsEnterpriseProxyId1", ids.proxies[0].id)
    ```


    :param Sequence[str] ids: A list of Proxy IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str tid: The ID of the tenant.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetInterRegionTrafficQosQueuesResult',
    'AwaitableGetInterRegionTrafficQosQueuesResult',
    'get_inter_region_traffic_qos_queues',
    'get_inter_region_traffic_qos_queues_output',
]

@pulumi.output_type
class GetInterRegionTrafficQosQueuesResult:
    """
    A collection of values returned by getInterRegionTrafficQosQueues.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, queues=None, traffic_qos_policy_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if queues and not isinstance(queues, list):
            raise TypeError("Expected argument 'queues' to be a list")
        pulumi.set(__self__, "queues", queues)
        if traffic_qos_policy_id and not isinstance(traffic_qos_policy_id, str):
            raise TypeError("Expected argument 'traffic_qos_policy_id' to be a str")
        pulumi.set(__self__, "traffic_qos_policy_id", traffic_qos_policy_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Inter Region Traffic Qos Queue IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of name of Inter Region Traffic Qos Queues.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def queues(self) -> Sequence['outputs.GetInterRegionTrafficQosQueuesQueueResult']:
        """
        A list of Inter Region Traffic Qos Queue Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "queues")

    @property
    @pulumi.getter(name="trafficQosPolicyId")
    def traffic_qos_policy_id(self) -> str:
        """
        The ID of the traffic scheduling policy.
        """
        return pulumi.get(self, "traffic_qos_policy_id")


class AwaitableGetInterRegionTrafficQosQueuesResult(GetInterRegionTrafficQosQueuesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInterRegionTrafficQosQueuesResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            queues=self.queues,
            traffic_qos_policy_id=self.traffic_qos_policy_id)


def get_inter_region_traffic_qos_queues(ids: Optional[Sequence[str]] = None,
                                        name_regex: Optional[str] = None,
                                        output_file: Optional[str] = None,
                                        traffic_qos_policy_id: Optional[str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInterRegionTrafficQosQueuesResult:
    """
    This data source provides Cen Inter Region Traffic Qos Queue available to the user.

    > **NOTE:** Available in 1.195.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_inter_region_traffic_qos_queues(ids=[alicloud_cen_inter_region_traffic_qos_queue["default"]["id"]],
        name_regex=alicloud_cen_inter_region_traffic_qos_queue["default"]["name"],
        traffic_qos_policy_id="qos-xxxxxxx")
    pulumi.export("alicloudCenInterRegionTrafficQosQueueExampleId", default.queues[0].id)
    ```


    :param Sequence[str] ids: A list of Inter Region Traffic Qos Queue IDs.
    :param str name_regex: A regex string to filter results by Group Metric Rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str traffic_qos_policy_id: The ID of the traffic scheduling policy.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['trafficQosPolicyId'] = traffic_qos_policy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getInterRegionTrafficQosQueues:getInterRegionTrafficQosQueues', __args__, opts=opts, typ=GetInterRegionTrafficQosQueuesResult).value

    return AwaitableGetInterRegionTrafficQosQueuesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        queues=pulumi.get(__ret__, 'queues'),
        traffic_qos_policy_id=pulumi.get(__ret__, 'traffic_qos_policy_id'))


@_utilities.lift_output_func(get_inter_region_traffic_qos_queues)
def get_inter_region_traffic_qos_queues_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                               name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                               traffic_qos_policy_id: Optional[pulumi.Input[str]] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInterRegionTrafficQosQueuesResult]:
    """
    This data source provides Cen Inter Region Traffic Qos Queue available to the user.

    > **NOTE:** Available in 1.195.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_inter_region_traffic_qos_queues(ids=[alicloud_cen_inter_region_traffic_qos_queue["default"]["id"]],
        name_regex=alicloud_cen_inter_region_traffic_qos_queue["default"]["name"],
        traffic_qos_policy_id="qos-xxxxxxx")
    pulumi.export("alicloudCenInterRegionTrafficQosQueueExampleId", default.queues[0].id)
    ```


    :param Sequence[str] ids: A list of Inter Region Traffic Qos Queue IDs.
    :param str name_regex: A regex string to filter results by Group Metric Rule name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str traffic_qos_policy_id: The ID of the traffic scheduling policy.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PrefixListArgs', 'PrefixList']

@pulumi.input_type
class PrefixListArgs:
    def __init__(__self__, *,
                 entrys: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 max_entries: Optional[pulumi.Input[int]] = None,
                 prefix_list_description: Optional[pulumi.Input[str]] = None,
                 prefix_list_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a PrefixList resource.
        :param pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]] entrys: The CIDR address block list of the prefix list.See the following `Block Entrys`.
        :param pulumi.Input[str] ip_version: The IP version of the prefix list. Value:-**IPV4**:IPv4 version.-**IPV6**:IPv6 version.
        :param pulumi.Input[int] max_entries: The maximum number of entries for CIDR address blocks in the prefix list.
        :param pulumi.Input[str] prefix_list_description: The description of the prefix list.It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix list. The name must be 2 to 128 characters in length, and must start with a letter. It can contain digits, periods (.), underscores (_), and hyphens (-).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the PrefixList belongs.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of PrefixList.
        """
        if entrys is not None:
            pulumi.set(__self__, "entrys", entrys)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if max_entries is not None:
            pulumi.set(__self__, "max_entries", max_entries)
        if prefix_list_description is not None:
            pulumi.set(__self__, "prefix_list_description", prefix_list_description)
        if prefix_list_name is not None:
            pulumi.set(__self__, "prefix_list_name", prefix_list_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def entrys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]]]:
        """
        The CIDR address block list of the prefix list.See the following `Block Entrys`.
        """
        return pulumi.get(self, "entrys")

    @entrys.setter
    def entrys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]]]):
        pulumi.set(self, "entrys", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[str]]:
        """
        The IP version of the prefix list. Value:-**IPV4**:IPv4 version.-**IPV6**:IPv6 version.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of entries for CIDR address blocks in the prefix list.
        """
        return pulumi.get(self, "max_entries")

    @max_entries.setter
    def max_entries(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_entries", value)

    @property
    @pulumi.getter(name="prefixListDescription")
    def prefix_list_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the prefix list.It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "prefix_list_description")

    @prefix_list_description.setter
    def prefix_list_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix_list_description", value)

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the prefix list. The name must be 2 to 128 characters in length, and must start with a letter. It can contain digits, periods (.), underscores (_), and hyphens (-).
        """
        return pulumi.get(self, "prefix_list_name")

    @prefix_list_name.setter
    def prefix_list_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix_list_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group to which the PrefixList belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The tags of PrefixList.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _PrefixListState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 entrys: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 max_entries: Optional[pulumi.Input[int]] = None,
                 prefix_list_associations: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListAssociationArgs']]]] = None,
                 prefix_list_description: Optional[pulumi.Input[str]] = None,
                 prefix_list_id: Optional[pulumi.Input[str]] = None,
                 prefix_list_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 share_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        Input properties used for looking up and filtering PrefixList resources.
        :param pulumi.Input[str] create_time: The time when the prefix list was created.
        :param pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]] entrys: The CIDR address block list of the prefix list.See the following `Block Entrys`.
        :param pulumi.Input[str] ip_version: The IP version of the prefix list. Value:-**IPV4**:IPv4 version.-**IPV6**:IPv6 version.
        :param pulumi.Input[int] max_entries: The maximum number of entries for CIDR address blocks in the prefix list.
        :param pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListAssociationArgs']]] prefix_list_associations: The association list information of the prefix list.
        :param pulumi.Input[str] prefix_list_description: The description of the prefix list.It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] prefix_list_id: The ID of the query Prefix List.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix list. The name must be 2 to 128 characters in length, and must start with a letter. It can contain digits, periods (.), underscores (_), and hyphens (-).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the PrefixList belongs.
        :param pulumi.Input[str] share_type: The share type of the prefix list. Value:-**Shared**: indicates that the prefix list is a Shared prefix list.-Null: indicates that the prefix list is not a shared prefix list.
        :param pulumi.Input[str] status: Resource attribute fields that represent the status of the resource.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of PrefixList.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if entrys is not None:
            pulumi.set(__self__, "entrys", entrys)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if max_entries is not None:
            pulumi.set(__self__, "max_entries", max_entries)
        if prefix_list_associations is not None:
            pulumi.set(__self__, "prefix_list_associations", prefix_list_associations)
        if prefix_list_description is not None:
            pulumi.set(__self__, "prefix_list_description", prefix_list_description)
        if prefix_list_id is not None:
            pulumi.set(__self__, "prefix_list_id", prefix_list_id)
        if prefix_list_name is not None:
            pulumi.set(__self__, "prefix_list_name", prefix_list_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if share_type is not None:
            pulumi.set(__self__, "share_type", share_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the prefix list was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def entrys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]]]:
        """
        The CIDR address block list of the prefix list.See the following `Block Entrys`.
        """
        return pulumi.get(self, "entrys")

    @entrys.setter
    def entrys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListEntryArgs']]]]):
        pulumi.set(self, "entrys", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[str]]:
        """
        The IP version of the prefix list. Value:-**IPV4**:IPv4 version.-**IPV6**:IPv6 version.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of entries for CIDR address blocks in the prefix list.
        """
        return pulumi.get(self, "max_entries")

    @max_entries.setter
    def max_entries(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_entries", value)

    @property
    @pulumi.getter(name="prefixListAssociations")
    def prefix_list_associations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListAssociationArgs']]]]:
        """
        The association list information of the prefix list.
        """
        return pulumi.get(self, "prefix_list_associations")

    @prefix_list_associations.setter
    def prefix_list_associations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrefixListPrefixListAssociationArgs']]]]):
        pulumi.set(self, "prefix_list_associations", value)

    @property
    @pulumi.getter(name="prefixListDescription")
    def prefix_list_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the prefix list.It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "prefix_list_description")

    @prefix_list_description.setter
    def prefix_list_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix_list_description", value)

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the query Prefix List.
        """
        return pulumi.get(self, "prefix_list_id")

    @prefix_list_id.setter
    def prefix_list_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix_list_id", value)

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the prefix list. The name must be 2 to 128 characters in length, and must start with a letter. It can contain digits, periods (.), underscores (_), and hyphens (-).
        """
        return pulumi.get(self, "prefix_list_name")

    @prefix_list_name.setter
    def prefix_list_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix_list_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group to which the PrefixList belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="shareType")
    def share_type(self) -> Optional[pulumi.Input[str]]:
        """
        The share type of the prefix list. Value:-**Shared**: indicates that the prefix list is a Shared prefix list.-Null: indicates that the prefix list is not a shared prefix list.
        """
        return pulumi.get(self, "share_type")

    @share_type.setter
    def share_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "share_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Resource attribute fields that represent the status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The tags of PrefixList.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


class PrefixList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entrys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PrefixListEntryArgs']]]]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 max_entries: Optional[pulumi.Input[int]] = None,
                 prefix_list_description: Optional[pulumi.Input[str]] = None,
                 prefix_list_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        """
        Provides a Vpc Prefix List resource. This resource is used to create a prefix list.

        For information about Vpc Prefix List and how to use it, see [What is Prefix List](https://www.alibabacloud.com/help/zh/virtual-private-cloud/latest/creatvpcprefixlist).

        > **NOTE:** Available in v1.182.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-testacc-example"
        default_rg = alicloud.resourcemanager.ResourceGroup("defaultRg",
            display_name="tf-testacc-chenyi",
            resource_group_name=name)
        change_rg = alicloud.resourcemanager.ResourceGroup("changeRg",
            display_name="tf-testacc-chenyi-change",
            resource_group_name=f"{name}1")
        default = alicloud.vpc.PrefixList("default",
            max_entries=50,
            resource_group_id=default_rg.id,
            prefix_list_description="test",
            ip_version="IPV4",
            prefix_list_name=name,
            entrys=[alicloud.vpc.PrefixListEntryArgs(
                cidr="192.168.0.0/16",
                description="test",
            )])
        ```

        ## Import

        Vpc Prefix List can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:vpc/prefixList:PrefixList example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PrefixListEntryArgs']]]] entrys: The CIDR address block list of the prefix list.See the following `Block Entrys`.
        :param pulumi.Input[str] ip_version: The IP version of the prefix list. Value:-**IPV4**:IPv4 version.-**IPV6**:IPv6 version.
        :param pulumi.Input[int] max_entries: The maximum number of entries for CIDR address blocks in the prefix list.
        :param pulumi.Input[str] prefix_list_description: The description of the prefix list.It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix list. The name must be 2 to 128 characters in length, and must start with a letter. It can contain digits, periods (.), underscores (_), and hyphens (-).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the PrefixList belongs.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of PrefixList.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PrefixListArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Vpc Prefix List resource. This resource is used to create a prefix list.

        For information about Vpc Prefix List and how to use it, see [What is Prefix List](https://www.alibabacloud.com/help/zh/virtual-private-cloud/latest/creatvpcprefixlist).

        > **NOTE:** Available in v1.182.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-testacc-example"
        default_rg = alicloud.resourcemanager.ResourceGroup("defaultRg",
            display_name="tf-testacc-chenyi",
            resource_group_name=name)
        change_rg = alicloud.resourcemanager.ResourceGroup("changeRg",
            display_name="tf-testacc-chenyi-change",
            resource_group_name=f"{name}1")
        default = alicloud.vpc.PrefixList("default",
            max_entries=50,
            resource_group_id=default_rg.id,
            prefix_list_description="test",
            ip_version="IPV4",
            prefix_list_name=name,
            entrys=[alicloud.vpc.PrefixListEntryArgs(
                cidr="192.168.0.0/16",
                description="test",
            )])
        ```

        ## Import

        Vpc Prefix List can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:vpc/prefixList:PrefixList example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PrefixListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrefixListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entrys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PrefixListEntryArgs']]]]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 max_entries: Optional[pulumi.Input[int]] = None,
                 prefix_list_description: Optional[pulumi.Input[str]] = None,
                 prefix_list_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrefixListArgs.__new__(PrefixListArgs)

            __props__.__dict__["entrys"] = entrys
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["max_entries"] = max_entries
            __props__.__dict__["prefix_list_description"] = prefix_list_description
            __props__.__dict__["prefix_list_name"] = prefix_list_name
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["prefix_list_associations"] = None
            __props__.__dict__["prefix_list_id"] = None
            __props__.__dict__["share_type"] = None
            __props__.__dict__["status"] = None
        super(PrefixList, __self__).__init__(
            'alicloud:vpc/prefixList:PrefixList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            entrys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PrefixListEntryArgs']]]]] = None,
            ip_version: Optional[pulumi.Input[str]] = None,
            max_entries: Optional[pulumi.Input[int]] = None,
            prefix_list_associations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PrefixListPrefixListAssociationArgs']]]]] = None,
            prefix_list_description: Optional[pulumi.Input[str]] = None,
            prefix_list_id: Optional[pulumi.Input[str]] = None,
            prefix_list_name: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            share_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, Any]]] = None) -> 'PrefixList':
        """
        Get an existing PrefixList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The time when the prefix list was created.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PrefixListEntryArgs']]]] entrys: The CIDR address block list of the prefix list.See the following `Block Entrys`.
        :param pulumi.Input[str] ip_version: The IP version of the prefix list. Value:-**IPV4**:IPv4 version.-**IPV6**:IPv6 version.
        :param pulumi.Input[int] max_entries: The maximum number of entries for CIDR address blocks in the prefix list.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PrefixListPrefixListAssociationArgs']]]] prefix_list_associations: The association list information of the prefix list.
        :param pulumi.Input[str] prefix_list_description: The description of the prefix list.It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        :param pulumi.Input[str] prefix_list_id: The ID of the query Prefix List.
        :param pulumi.Input[str] prefix_list_name: The name of the prefix list. The name must be 2 to 128 characters in length, and must start with a letter. It can contain digits, periods (.), underscores (_), and hyphens (-).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the PrefixList belongs.
        :param pulumi.Input[str] share_type: The share type of the prefix list. Value:-**Shared**: indicates that the prefix list is a Shared prefix list.-Null: indicates that the prefix list is not a shared prefix list.
        :param pulumi.Input[str] status: Resource attribute fields that represent the status of the resource.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of PrefixList.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrefixListState.__new__(_PrefixListState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["entrys"] = entrys
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["max_entries"] = max_entries
        __props__.__dict__["prefix_list_associations"] = prefix_list_associations
        __props__.__dict__["prefix_list_description"] = prefix_list_description
        __props__.__dict__["prefix_list_id"] = prefix_list_id
        __props__.__dict__["prefix_list_name"] = prefix_list_name
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["share_type"] = share_type
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return PrefixList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The time when the prefix list was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def entrys(self) -> pulumi.Output[Optional[Sequence['outputs.PrefixListEntry']]]:
        """
        The CIDR address block list of the prefix list.See the following `Block Entrys`.
        """
        return pulumi.get(self, "entrys")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[str]:
        """
        The IP version of the prefix list. Value:-**IPV4**:IPv4 version.-**IPV6**:IPv6 version.
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter(name="maxEntries")
    def max_entries(self) -> pulumi.Output[int]:
        """
        The maximum number of entries for CIDR address blocks in the prefix list.
        """
        return pulumi.get(self, "max_entries")

    @property
    @pulumi.getter(name="prefixListAssociations")
    def prefix_list_associations(self) -> pulumi.Output[Sequence['outputs.PrefixListPrefixListAssociation']]:
        """
        The association list information of the prefix list.
        """
        return pulumi.get(self, "prefix_list_associations")

    @property
    @pulumi.getter(name="prefixListDescription")
    def prefix_list_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the prefix list.It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "prefix_list_description")

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> pulumi.Output[str]:
        """
        The ID of the query Prefix List.
        """
        return pulumi.get(self, "prefix_list_id")

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the prefix list. The name must be 2 to 128 characters in length, and must start with a letter. It can contain digits, periods (.), underscores (_), and hyphens (-).
        """
        return pulumi.get(self, "prefix_list_name")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group to which the PrefixList belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="shareType")
    def share_type(self) -> pulumi.Output[str]:
        """
        The share type of the prefix list. Value:-**Shared**: indicates that the prefix list is a Shared prefix list.-Null: indicates that the prefix list is not a shared prefix list.
        """
        return pulumi.get(self, "share_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Resource attribute fields that represent the status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        The tags of PrefixList.
        """
        return pulumi.get(self, "tags")

